==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/config-extend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

settype($act, "string");
if ($act == "bosinit") {
   SqlQuery("update T_Counter set Hit = 0");
} else if ($act == "timeinit") {
   SqlQuery("delete from T_Stats_date");
   SqlQuery("update T_Stats_hour set hits = 0");
   SqlQuery("update T_Stats_month set hits = 0");
   SqlQuery("update T_Stats_week set hits = 0");
}

$head = _EXTCONT;
include("../include/header.inc.php");

$VAR["Heading"] = _EXTCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
   <td>Trackback</td><td>".
   $out->radio("trackback",array(_NOTUSE,_USE),$CONF['trackback']) ."
</td>
</tr>
<tr>
   <td>Trackback Ping</td><td>".
   $out->radio("trackping",array(_NOTUSE,_USE),$CONF['trackping']) ."
</td>
<tr>
   <td>". _TBMSG_LENGTH ."</td><td>".
   $out->input_form("text","tbmsg_length",$CONF['tbmsg_length'],KWL_FormSize(3),4) . _CHARACTER ." (0=". _NOTUSE .")</td>
</tr>
<tr>
   <td>". _TBMSG_SHOW ."</td><td>".
   $out->radio("tbmsg_show",array(_NOTUSE,_USE),$CONF['tbmsg_show']) ."
</td>
</tr>
<tr>
   <td>HTTP Referer</td>
   <td>". $out->radio("Referer",array(_NOTUSE,_USE),$CONF['Referer']) ."
   <br />". _REFER_LIMIT .": "
   . $out->select("Referer_limit",array( 0 => _REFER_LIMIT_NO,
                                        500 => 500,
                                        1000 => 1000,
                                        2000 => 2000,
                                        3000 => 3000,
                                        4000 => 4000,
                                        5000 => 5000,
                                        10000 => 10000),
                   $CONF['Referer_limit']) ."
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _LINKS ."</td>
	<td>". $out->select("Links",array(_NOTUSE,_LINK_ANYONE,_LINK_ONLYADMIN,_LINK_FREE),$CONF['Links']) ."</td>
</tr>

<tr>
	<td>". _STATS ."</td>
	<td>". $out->radio("SiteStats",array(_NOTUSE,_USE),$CONF['SiteStats']) ."</td>
</tr>

<tr>
	<td>". _COUNTER ."</td>
	<td>". $out->radio("Counter",array(_NOTUSE,_USE),$CONF['Counter']) ."
   (<a href=\"config-extend.php?act=bosinit\">". _COUNT_INIT ."</a>)
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _TIME_COUNTER ."</td>
	<td>". $out->radio("Time_Counter",array(_NOTUSE,_USE),$CONF['Time_Counter']) ."
   (<a href=\"config-extend.php?act=timeinit\">". _COUNT_INIT ."</a>)
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _ARCHIVE ."</td>
	<td>". $out->radio("Archive",array(_NOTUSE,_USE),$CONF['Archive']) ."</td>
</tr>

<tr>
   <td>". _DOWNLOAD ."</td>
   <td>". $out->radio("download",array(_NOTUSE,_USE),$CONF['download']) ."</td>
</tr>

<tr>
   <td>FAQ</td>
   <td>". $out->radio("FAQ",array(_NOTUSE,_USE),$CONF['FAQ']) ."</td>
</tr>

<tr>
   <td>Apache Style log</td>
   <td>". $out->radio("apache_log",array(_NOTUSE,_USE),$CONF['apache_log']) ."
	<br />log file: $CONF[G_PATH]/logs/access_log</td>
</tr>
<tr>
	<td colspan=\"2\">"
   . $out->input_form("hidden","what","config-extend")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/config-extend.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

settype($act, "string");
if ($act == "bosinit") {
   SqlQuery("update T_Counter set Hit = 0");
} else if ($act == "timeinit") {
   SqlQuery("delete from T_Stats_date");
   SqlQuery("update T_Stats_hour set hits = 0");
   SqlQuery("update T_Stats_month set hits = 0");
   SqlQuery("update T_Stats_week set hits = 0");
}

$head = _EXTCONT;
include("../include/header.inc.php");

$VAR["Heading"] = _EXTCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
   <td>Trackback</td><td>".
   $out->radio("trackback",array(_NOTUSE,_USE),$CONF['trackback']) ."
</td>
</tr>
<tr>
   <td>Trackback Ping</td><td>".
   $out->radio("trackping",array(_NOTUSE,_USE),$CONF['trackping']) ."
</td>
<tr>
   <td>". _TBMSG_LENGTH ."</td><td>".
   $out->input_form("text","tbmsg_length",$CONF['tbmsg_length'],KWL_FormSize(3),4) . _CHARACTER ." (0=". _NOTUSE .")</td>
</tr>
<tr>
	<td>". _EXCERPT_PARSE_LEVEL ."</td>
   <td>". $out->select("excerpt_parse",array( 0 => _PARSE_L0,
                                             2 => _PARSE_L2,
                                             3 => _PARSE_L3,
                                             4 => _PARSE_L4,
                                             5 => _PARSE_L5 ),
                       $CONF['excerpt_parse']) ."
   </td>
</tr>
<tr>
   <td>". _TBMSG_SHOW ."</td><td>".
   $out->radio("tbmsg_show",array(_NOTUSE,_USE),$CONF['tbmsg_show']) ."
</td>
</tr>
<tr>
   <td>HTTP Referer</td>
   <td>". $out->radio("Referer",array(_NOTUSE,_USE),$CONF['Referer']) ."
   <br />". _REFER_LIMIT .": "
   . $out->select("Referer_limit",array( 0 => _REFER_LIMIT_NO,
                                        500 => 500,
                                        1000 => 1000,
                                        2000 => 2000,
                                        3000 => 3000,
                                        4000 => 4000,
                                        5000 => 5000,
                                        10000 => 10000),
                   $CONF['Referer_limit']) ."
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _LINKS ."</td>
	<td>". $out->select("Links",array(_NOTUSE,_LINK_ANYONE,_LINK_ONLYADMIN,_LINK_FREE),$CONF['Links']) ."</td>
</tr>

<tr>
	<td>". _STATS ."</td>
	<td>". $out->radio("SiteStats",array(_NOTUSE,_USE),$CONF['SiteStats']) ."</td>
</tr>

<tr>
	<td>". _COUNTER ."</td>
	<td>". $out->radio("Counter",array(_NOTUSE,_USE),$CONF['Counter']) ."
   (<a href=\"config-extend.php?act=bosinit\">". _COUNT_INIT ."</a>)
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _TIME_COUNTER ."</td>
	<td>". $out->radio("Time_Counter",array(_NOTUSE,_USE),$CONF['Time_Counter']) ."
   (<a href=\"config-extend.php?act=timeinit\">". _COUNT_INIT ."</a>)
   <br />". _ONLY_SESSION ."
   </td>
</tr>

<tr>
	<td>". _ARCHIVE ."</td>
	<td>". $out->radio("Archive",array(_NOTUSE,_USE),$CONF['Archive']) ."</td>
</tr>

<tr>
   <td>". _DOWNLOAD ."</td>
   <td>". $out->radio("download",array(_NOTUSE,_USE),$CONF['download']) ."</td>
</tr>

<tr>
   <td>FAQ</td>
   <td>". $out->radio("FAQ",array(_NOTUSE,_USE),$CONF['FAQ']) ."</td>
</tr>

<tr>
   <td>Apache Style Log</td>
   <td>". $out->radio("apache_log",array(_NOTUSE,_USE),$CONF['apache_log']) ."
	<br />Log File:<br />$CONF[G_PATH]/logs/access_log</td>
</tr>
<tr>
	<td colspan=\"2\">"
   . $out->input_form("hidden","what","config-extend")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
